from setuptools import setup, find_packages
import os 
import codecs
setup (
    name="wassup_my_g",
    version="0.0.2",
    author="Shefki Berisha",
    author_email="mastibeatz16@gmail.com",
    description="The most useless package ever.",
    long_description="Why would you use this? 💀",
    pythonrequires=">=3.8.0"
)